@@ -7,6 +7,7 @@
 class MockAccount : public AbstractAccount
 {
     Q_OBJECT
+
 public:
     MockAccount(QObject *parent = nullptr);
     void get(const QUrl &url,
@@ -49,6 +50,9 @@ public:
 
     void registerGet(const QUrl &url, QNetworkReply *reply);
 
+    void setFakeIdentity(const QJsonObject &object);
+    void clearFakeIdentity();
+
 private:
     QHash<QUrl, QNetworkReply *> m_postReplies;
     QHash<QUrl, QNetworkReply *> m_getReplies;
