@@ -180,7 +180,7 @@ void AbstractTimelineModel::actionFavorite(const QModelIndex &index, Post *post)
         post->setFavourited(false);
     }
 
-    Q_EMIT dataChanged(index, index);
+    Q_EMIT dataChanged(index, index, {FavouritedRole});
 }
 
 void AbstractTimelineModel::actionRepeat(const QModelIndex &index, Post *post)
@@ -193,7 +193,7 @@ void AbstractTimelineModel::actionRepeat(const QModelIndex &index, Post *post)
         post->setReblogged(false);
     }
 
-    Q_EMIT dataChanged(index, index);
+    Q_EMIT dataChanged(index, index, {RebloggedRole});
 }
 
 void AbstractTimelineModel::actionRedraft(const QModelIndex &index, Post *post, bool isEdit)
@@ -237,7 +237,7 @@ void AbstractTimelineModel::actionBookmark(const QModelIndex &index, Post *post)
         post->setBookmarked(false);
     }
 
-    Q_EMIT dataChanged(index, index);
+    Q_EMIT dataChanged(index, index, {BookmarkedRole});
 }
 
 void AbstractTimelineModel::actionPin(const QModelIndex &index, Post *post)
@@ -250,7 +250,7 @@ void AbstractTimelineModel::actionPin(const QModelIndex &index, Post *post)
         post->setPinned(false);
     }
 
-    Q_EMIT dataChanged(index, index);
+    Q_EMIT dataChanged(index, index, {PinnedRole});
 }
 
 void AbstractTimelineModel::actionDelete(const QModelIndex &index, Post *post)
